@@ -17,7 +17,7 @@ test_that("Routing to errors and 404s works", {
   r$setErrorHandler(function(req, res, err){ errors <<- errors + 1; errRes })
   r$set404Handler(function(req, res){ notFounds <<- notFounds + 1; notFoundRes })
 
-  res <- PlumberResponse$new("json")
+  res <- PlumberResponse$new()
 
   expect_equal(r$route(make_req("GET", "/"), res), "first")
   expect_equal(r$route(make_req("GET", "/abc"), res), "abc get")
@@ -28,12 +28,12 @@ test_that("Routing to errors and 404s works", {
   expect_equal(notFounds, 0)
 
   nf <- r$route(make_req("GET", "/something-crazy"), res)
-  expect_equal(res$serializer, "json")
+  expect_equal(res$serializer, jsonSerializer())
   expect_equal(nf, notFoundRes)
   expect_equal(notFounds, 1)
 
   er <- r$route(make_req("GET", "/error"), res)
-  expect_equal(res$serializer, "json")
+  expect_equal(res$serializer, jsonSerializer())
   expect_equal(er, errRes)
   expect_equal(errors, 1)
 })
